<?php

require ( BP_MEDIA_PLUGIN_DIR . '/bp-media-classes.php' );
require ( BP_MEDIA_PLUGIN_DIR . '/bp-media-templatetags.php' );
require ( BP_MEDIA_PLUGIN_DIR . '/bp-media-ajax.php' );
require ( BP_MEDIA_PLUGIN_DIR . '/bp-media-admin.php' );
require ( BP_MEDIA_PLUGIN_DIR . '/lib-kaltura/KalturaClient.php' );

function bp_media_install() {
    global $wpdb, $bp;
    if ( ! empty($wpdb->charset) )
        $charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
    if ( ! empty($wpdb->collate) )
        $charset_collate .= " COLLATE $wpdb->collate";

    $sql[] = "CREATE TABLE {$bp->media->table_media_data} (
                            id bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
                            entry_id varchar(100),
                            user_id bigint(20) NOT NULL,
                            service_type varchar(100) DEFAULT 'kaltura' NOT NULL,
                            media_type int(10) ,
                            total_rating int(10) DEFAULT '1',
                            rating_counter int(10) DEFAULT '1',
                            rating int(10) DEFAULT '1',
                            views int(10) DEFAULT '1',
                            KEY (id)
                            ) {$charset_collate};";

    // var_dump($sql);
    require_once( ABSPATH . 'wp-admin/upgrade-functions.php' );
    dbDelta($sql);


    update_site_option( 'bp-media-db-version', BP_MEDIA_DB_VERSION );
}
//this is not operational as bp1.2 wire is completely changed and need to rethink the whole thing :kapil
function media_wire_install() {
    global $wpdb, $bp;

    if ( !empty($wpdb->charset) )
        $charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";

    $sql[] = "CREATE TABLE {$bp->media->table_name_wire} (
	  		id bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
			item_id bigint(20) NOT NULL,
			user_id bigint(20) NOT NULL,
			content longtext NOT NULL,
			date_posted datetime NOT NULL,
			KEY item_id (item_id),
			KEY user_id (user_id)
	 	   ) {$charset_collate};";

    require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
//    dbDelta($sql);
}

function media_user_rating_install() {
    global $wpdb, $bp;

    if ( !empty($wpdb->charset) )
        $charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";

    $sql[] = "CREATE TABLE {$bp->media->table_user_rating_data} (
	  		image_id int(11),
			user_id int(11)
	 	   ) {$charset_collate};";

    require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
    dbDelta($sql);
}

function media_setup_globals() {

    global $bp, $wpdb, $kaltura_validation_data,$ks;
    if(get_site_option('bp_rt_kaltura_url')) {
        $config         	= new KalturaConfiguration(get_site_option('bp_rt_kaltura_partner_id'));
        $config->serviceUrl     = get_site_option('bp_rt_kaltura_url');
        $client        		= new KalturaClient($config);

        $ks                     = $client->session->start(get_site_option( 'bp_rt_kaltura_admin_secret'), 'ANONYMOUS', KalturaSessionType::ADMIN);
        $client->setKs($ks);  // set the session in the client


        $kaltura_validation_data =
                array(
                'partner_id'            => get_site_option('bp_rt_kaltura_partner_id'),
                'subpartner_id'         => get_site_option('bp_rt_kaltura_subpartner_id'),
                'admin_secret'          => get_site_option( 'bp_rt_kaltura_admin_secret'),
                'secret'                => get_site_option( 'bp_rt_kaltura_secret'),
                'partnerUserID'         => 'ANONYMOUS'
        );

        $kaltura_validation_data['config']  = $config;
        $kaltura_validation_data['client']  = $client;
        $kaltura_validation_data['ks']      = $ks;
//        var_dump($kaltura_validation_data);
    }
    else {
        $media_msg = __("Please enter valid Partner Details for Kaltura");
        $media_notice = '<div class="updated fade"><p><strong>'.$media_msg.'</strong></p></div>';
        //fix this : message appearing twice
//        add_action('admin_menu', create_function("", 'echo \''.$media_notice.'\';'));
    }

    $bp->media->table_media_data = $wpdb->base_prefix . 'bp_media_data';
    $bp->media->table_user_rating_data = $wpdb->base_prefix . 'bp_media_user_rating_list';
    $bp->media->image_base = WP_PLUGIN_URL . '/images';
    $bp->media->format_activity_function = 'bp_media_format_activity';
    $bp->media->format_notification_function = 'bp_media_format_notifications';

    if ( function_exists('bp_wire_install') )
        $bp->media->table_name_wire = $wpdb->base_prefix . 'bp_media_wire';
    $bp->version_numbers->media = BP_MEDIA_VERSION;
    $bp->media->id = 'media';
    $bp->media->slug = BP_MEDIA_SLUG;
    $bp->active_components[$bp->media->slug] = $bp->media->id;
}
add_action( 'plugins_loaded', 'media_setup_globals', 5 );
add_action( 'admin_menu', 'media_setup_globals', 2 );

function media_add_admin_menu() {
    global $wpdb, $bp;


    if ( !is_site_admin() )
        return false;

    /* Add the administration tab under the "Site Admin" tab for site administrators */
    add_submenu_page('bp-general-settings', //$parent
            __('Kaltura Setting','Kaltura Setting'),//$page_title
            __('Kaltura Setting','Kaltura Setting'),//$menu_title
            'manage_options',//$access_level
            'bp-media-setup',//$file
            "media_admin" );//$function
}
add_action('admin_menu', 'media_add_admin_menu');

function bp_media_check_installed() {
    global $wpdb, $bp;

    if ( !is_site_admin() )
        return false;

//    require ( 'bp-media-admin.php' );
//    if ( get_site_option('bp-media-db-version') < BP_MEDIA_DB_VERSION )
    bp_media_install();
    media_wire_install();
    media_user_rating_install();
}
add_action( 'admin_menu', 'bp_media_check_installed' );
//
//add_action( 'admin_menu', 'bp_media_add_admin_menu' );


function bp_media_header_nav_setup() {//done
    global $bp;
    $selected = ( bp_is_page( BP_MEDIA_SLUG ) ) ? ' class="selected"' : '';
    $title = __( 'Media', 'Media' );
    echo sprintf('<li%s><a href="%s/%s" title="%s">%s</a></li>', $selected, get_option('home'), BP_MEDIA_SLUG, $title, $title );
}
add_action( 'bp_nav_items', 'bp_media_header_nav_setup', 100);

function media_setup_root_component() { //done
    bp_core_add_root_component( BP_MEDIA_SLUG );
}
add_action( 'plugins_loaded', 'media_setup_root_component', 2 );

function media_directory_media_setup() {
    global $bp;
    if ( $bp->current_component == BP_MEDIA_SLUG && !$bp->is_single_item && !$bp->displayed_user->id) {
        $bp->is_directory = true;
        bp_media_load_template( 'media/index' );
    }
}
add_action( 'wp', 'media_directory_media_setup', 2 );
function media_add_js() {
    $js_path = BP_MEDIA_PLUGIN_URL.'/themes/media/js/';
    wp_enqueue_script( 'bp-media-swfobject', $js_path.'swfobject.js');
    wp_enqueue_script( 'bp-media-rating', $js_path.'rating.js');
        wp_enqueue_script( 'bp-media-general', $js_path.'general.js');
}
add_action( 'wp_print_scripts', 'media_add_js', 1 );

function media_add_single_js() {
    global $bp;
//   var_dump($bp);
    $js_path = BP_MEDIA_PLUGIN_URL.'/themes/media/js/';
//    var_dump($js_path);
    $action = array("mediaall","photo","audio","video");
    $cc = $bp->current_component;
    $ca = $bp->current_action;
    $av = $bp->action_variables[0];
    if(in_array($ca, $action) && media == $cc && (!empty($av))){
        wp_deregister_script('bp-media-general');
        wp_enqueue_script( 'bp-media-single', $js_path.'single.js');
    }
}
add_action( 'wp_print_scripts', 'media_add_single_js', 1 );

function picture_new_wire_post( $picture_id, $content ) {
    global $bp;

    /* Check the nonce first. */
    if ( !check_admin_referer( 'bp_wire_post' ) )
        return false;

    $private = false;

    if ( $wire_post_id = bp_wire_new_post( $picture_id, $content, $bp->media->slug, $private ) ) {

        bp_core_add_notification( $picture_id, $bp->displayed_user->id, $bp->media->slug, 'picture_new_wire_post' );
        /*
        bp_picture_record_activity(
                    array(
                        'item_id' => $wire_post_id,
                        'user_id' => $bp->loggedin_user->id,
                        'component_name' => $bp->media->slug,
                        'component_action' => 'picture_new_wire_post',
                        'is_private' => 0
                    )
                );
 *
        */
        do_action( 'picture_new_wire_post', $picture_id, $content );

        return true;

    }

    return false;
}

function picture_delete_wire_post( $wire_post_id, $table_name ) {
    global $bp;

    /* Check the nonce first. */
    if ( !check_admin_referer( 'bp_media_wire_delete_link' ) )
        return false;

    if ( bp_wire_delete_post( $wire_post_id, $bp->media->slug, $table_name ) ) {
        /*
        bp_picture_delete_activity( array(
                                            'item_id' => $wire_post_id,
                                            'component_name' => $bp->media->slug,
                                            'component_action' => 'picture_new_wire_post',
                                            'user_id' => $bp->loggedin_user->id
                                    )
                                );

        */

        do_action( 'picture_deleted_wire_post', $wire_post_id );
        return true;
    }

    return false;
}

function bp_picture_record_activity( $args ) {
    if ( function_exists('bp_activity_record') ) {
        extract( (array)$args );
        bp_activity_record( $item_id, $component_name, $component_action, $is_private, $secondary_item_id, $user_id, $secondary_user_id, $recorded_time );
    }
}

function bp_picture_delete_activity( $args ) {
    if ( function_exists('bp_activity_delete') ) {
        extract( (array)$args );
        bp_activity_delete( $item_id, $component_name, $component_action, $user_id, $secondary_item_id );
    }
}

function bp_media_format_activity( $item_id, $user_id, $action, $secondary_item_id = false, $for_secondary_user = false ) {
    global $bp;

    /* $action is the 'component_action' variable set in the record function. */
    switch( $action ) {
        case 'picture_new_wire_post':

            $wire_post = new BP_Wire_Post( $bp->media->table_name_wire, $item_id );

            if (!$wire_post || !$wire_post->content )
                return false;

            $user_link = bp_core_get_userlink( $user_id );
            $picture_link = bp_get_picture_permalink( $wire_post->item_id);
            $post_excerpt = bp_create_excerpt( $wire_post->content );

            $content = sprintf ( __('%s wrote on the wire of %s', 'buddypress'), $user_link, '<a href="'.$picture_link.'">picture</a>' ) . ' <span class="time-since">%s</span>';
            $content .= '<blockquote>' . $post_excerpt . '</blockquote>';

            $content = apply_filters( 'bp_media_wire_post_activity', $content, $user_link, $post_excerpt );

            return array(
                    'primary_link' => $group_link,
                    'content' => $content
            );
            break;
    }

    /* By adding a do_action here, people can extend your component with new activity items. */
    do_action( 'bp_media_format_activity', $action, $item_id, $user_id, $action, $secondary_item_id, $for_secondary_user );

    return false;
}

function bp_media_screen_notification_settings() {
    global $current_user;
    ?>
<table class="notification-settings" id="bp-media-notification-settings">
    <tr>
        <th class="icon"></th>
        <th class="title"><?php _e( 'Picture Media', 'bp-media' ) ?></th>
        <th class="yes"><?php _e( 'Yes', 'bp-media' ) ?></th>
        <th class="no"><?php _e( 'No', 'bp-media' )?></th>
    </tr>
    <tr>
        <td></td>
        <td><?php _e( 'A member post wire on picture', 'bp-media' ) ?></td>
        <td class="yes"><input type="radio" name="notifications[notification_wire_post_picture]" value="yes" <?php if ( !get_usermeta( $current_user->id,'notification_wire_post_picture') || 'yes' == get_usermeta( $current_user->id,'notification_wire_post_picture') ) { ?>checked="checked" <?php } ?>/></td>
        <td class="no"><input type="radio" name="notifications[notification_wire_post_picture]" value="no" <?php if ( get_usermeta( $current_user->id,'notification_wire_post_picture') == 'no' ) { ?>checked="checked" <?php } ?>/></td>
    </tr>
        <?php do_action( 'bp_media_notification_settings' ); ?>
</table>
    <?php
}
add_action( 'bp_notification_settings', 'bp_media_screen_notification_settings' );

function bp_media_format_notifications( $action, $item_id, $secondary_item_id, $total_items ) {
    global $bp;

    switch ( $action ) {
        case 'picture_new_wire_post':

            if ( (int)$total_items > 1 ) {
                return apply_filters( 'bp_media_picture_new_wire_post_notification', '<a href="' . $bp->loggedin_user->domain . $bp->media->slug . '/picture/"' . '">' . sprintf( __( '%d New Wire Posts on Picture', 'bp-media' ), (int)$total_items ) . '</a>', $total_items );
            } else {
                return apply_filters( 'bp_media_picture_new_wire_post_notification', '<a href="' . $bp->loggedin_user->domain . $bp->media->slug .'/picture/'.$item_id.'">' . __( 'New Wire Post on Picture', 'bp-media' ). '</a>', $item_id);
            }
            break;
    }

    do_action( 'bp_media_format_notifications', $action, $item_id, $secondary_item_id, $total_items );

    return false;
}



function bp_media_remove_screen_notifications() {
    global $bp;
    bp_core_delete_notifications_for_user_by_type( $bp->loggedin_user->id, $bp->media->slug, 'picture_new_wire_post' );
}
add_action( 'bp_media_picture', 'bp_media_remove_screen_notifications' );

/*
 * More functions to retrive pictures
*/

function bp_pictures_get_pictures_for_user( $user_id, $media_type ) {

    return BP_Media_Picture::get_pictures_for_user( $user_id,$media_type);
}

function media_setup_nav() {
    global $bp;

    //Single page template is loaded here....
    if($bp->action_variables[0] && is_media_exists($bp->action_variables[0])) {
        $bp->is_single_item = true;
        bp_core_load_template( apply_filters( 'media_template_media_home', 'media/single/home' ) );
    }
    $counter_indicator = (10);
//    bp_core_new_nav_item( array(
//        'name' => sprintf( __( 'Media<span>(%d)</span>', 'media' ), 10 ),
//        'slug' => $bp->media->slug,
//        'position' => 80,
//        'screen_function' => 'media_screen_photo',
//        'default_subnav_slug' => 'my-media',
//        'item_css_id' => $bp->media->id )
//            );

//    		'name' => false, // Display name for the nav item
//		'slug' => false, // URL slug for the nav item
//		'item_css_id' => false, // The CSS ID to apply to the HTML of the nav item
//		'show_for_displayed_user' => true, // When viewing another user does this nav item show up?
//		'site_admin_only' => false, // Can only site admins see this nav item?
//		'position' => 99, // Index of where this nav item should be positioned
//		'screen_function' => false, // The name of the function to run when clicked
//		'default_subnav_slug' => false // The slug of the default subnav item to select when clicked


    $media_link = $link = $bp->loggedin_user->domain . $bp->media->slug . '/';
//        echo $media_link;
    /* Add the subnav items to the groups nav item */
//    bp_core_new_subnav_item( array(
//        'name' => __( 'All Media', 'media' ) . $count_indicator,
//        'slug' => 'media-all',
//        'parent_url' => $media_link,
//        'parent_slug' => $bp->media->slug,
//        'screen_function' => 'media_screen_photo',
//        'position' => 10,
//        'item_css_id' => 'media-mediaall',
//        'user_has_access' => true )
//            );

//                'name' => __( 'Followers', 'classifieds' ),
//                'slug' => __('followers','classifieds-slugs'),
//                'parent_url' => $classified_link,
//                'parent_slug' => $bp->classifieds->slug,
//                'screen_function' => 'classifieds_screen_classified_followers',
//                'position' => 60,
//                'item_css_id' => 'classified-followers',
//                'user_has_access'=>$view_subnav_followers)


    
//    		'name' => false, // Display name for the nav item
//		'slug' => false, // URL slug for the nav item
//		'parent_slug' => false, // URL slug of the parent nav item
//		'parent_url' => false, // URL of the parent item
//		'item_css_id' => false, // The CSS ID to apply to the HTML of the nav item
//		'user_has_access' => true, // Can the logged in user see this nav item?
//		'site_admin_only' => false, // Can only site admins see this nav item?
//		'position' => 90, // Index of where this nav item should be positioned
//		'screen_function' => false // The name of the function to run when clicked


//    bp_core_new_subnav_item( array( 'name' => __( 'Photos', 'media' ) . $count_indicator, 'slug' => 'photo', 'parent_url' => $media_link, 'parent_slug' => $bp->media->slug, 'screen_function' => 'media_screen_photo', 'position' => 10, 'user_has_access' => true ) );
//    bp_core_new_subnav_item( array( 'name' => __( 'Audio', 'media' ), 'slug' => 'audio', 'parent_url' => $media_link, 'parent_slug' => $bp->media->slug, 'screen_function' => 'media_screen_audio', 'position' => 20, 'user_has_access' => true ) );
//    bp_core_new_subnav_item( array( 'name' => __( 'Video', 'media' ), 'slug' => 'video', 'parent_url' => $media_link, 'parent_slug' => $bp->media->slug, 'screen_function' => 'media_screen_video', 'position' => 30, 'user_has_access' => true ) );
//    bp_core_new_subnav_item( array( 'name' => __( 'Upload', 'media' ), 'slug' => 'upload', 'parent_url' => $media_link, 'parent_slug' => $bp->media->slug, 'screen_function' => 'media_screen_upload', 'position' => 90, 'user_has_access' => true ) );
//

    do_action( 'media_setup_nav');

}

add_action( 'plugins_loaded', 'media_setup_nav' );
add_action( 'admin_menu', 'media_setup_nav' );

function media_screen_photo() {
    do_action( 'media_screen_photo' );
    bp_core_load_template( apply_filters( 'media_template_photo', 'members/single/home' ) );
}

function media_screen_audio() {
    do_action( 'media_screen_audio' );
    bp_core_load_template( apply_filters( 'media_screen_audio', 'members/single/home' ) );
}

function media_screen_video() {
    do_action( 'media_screen_video' );
    bp_core_load_template( apply_filters( 'media_screen_video', 'members/single/home' ) );
}

function media_screen_upload() {
    do_action( 'media_screen_upload' );
    bp_core_load_template( apply_filters( 'media_screen_upload', 'members/single/home' ) );
}

function media_members_content() {
    bp_media_locate_template( array( 'media/single/media.php' ), true );
}
add_action('bp_after_member_body','media_members_content');

function media_add_css() {
    if (bp_is_user_media()) {
        $css_file_path = BP_MEDIA_PLUGIN_URL."/themes/media/css/";
        wp_enqueue_style( 'bp-media-structure', $css_file_path.'media.css');
        wp_enqueue_style( 'bp-media-rate', $css_file_path.'rating.css');
    }
}
add_action( 'wp_print_styles', 'media_add_css' );

function media_change_title_callback() {
    $id = $_POST['id'];
    $new_title = $_POST['new_title'];
    global $wpdb,$bp,$kaltura_validation_data; // this is how you get access to the database
//    echo $id;
    $bp->media->table_media_data = $wpdb->base_prefix . 'bp_media_data';
    $e_id = $wpdb->get_var($wpdb->prepare("SELECT entry_id from {$bp->media->table_media_data} WHERE id = {$id} "));
//    echo $e_id;
    try {
        $k = new KalturaMediaEntry();
        $k->name=$new_title;
        $kaltura_validation_data['client']->media->update($e_id,$k);
         echo $new_title;
    }
    catch(Exception $e) {
        echo e. "Error";
    }
    die();
}
add_action('wp_ajax_media_change_title', 'media_change_title_callback');
add_action('wp_ajax_nopriv_media_change_title', 'media_change_title_callback');

function media_change_description_callback() {
    $id = $_POST['id'];
    $new_desc = $_POST['new_desc'];
//    echo $id.'  '.$new_title;
    global $wpdb,$bp,$kaltura_validation_data; // this is how you get access to the database
    $bp->media->table_media_data = $wpdb->base_prefix . 'bp_media_data';
    $e_id = $wpdb->get_var($wpdb->prepare("SELECT entry_id from {$bp->media->table_media_data} WHERE id = {$id} "));
    try {
        $k = new KalturaMediaEntry();
        $k->description=$new_desc;
        $kaltura_validation_data['client']->media->update($e_id,$k);
        echo $new_desc;
    }
    catch(Exception $e) {
        echo e. "Error";
    }
    die();
}
add_action('wp_ajax_media_change_description', 'media_change_description_callback');
add_action('wp_ajax_nopriv_media_change_description', 'media_chage_description_callback');

function media_user_rating_callback() {
    $rating = $_POST['rating'];
    $image_id = $_POST['image_id'];
    $user_id = $_POST['user_id'];
    global $wpdb, $bp;
    //$bp->media->table_name_wire = $wpdb->base_prefix . 'bp_media_wire';
    $bp->media->table_media_data = $wpdb->base_prefix . 'bp_media_data';
    $bp->media->table_media_rating = $wpdb->base_prefix . 'bp_media_user_rating_list';
    $result = $wpdb->query("SELECT * FROM {$bp->media->table_media_rating} WHERE image_id = {$image_id} AND user_id = {$user_id} ");

    if(empty($result)) {
        $wpdb->query("UPDATE {$bp->media->table_media_data} SET total_rating = total_rating + {$rating}, rating_counter= rating_counter + 1 WHERE ID = {$image_id} ");
        $wpdb->query("INSERT INTO {$bp->media->table_media_rating} (image_id, user_id) VALUES ({$image_id},{$user_id}) ");
        echo 'THANKS / ';
    }
    else {
        echo "ALREADY VOTED / " ;
    }

    die();
}
add_action('wp_ajax_media_user_rating', 'media_user_rating_callback');
add_action('wp_ajax_nopriv_media_user-rating', 'media_user_rating_callback');

function media_view_update_callback() {

    $image_id = $_POST['image_id'];
    global $wpdb, $bp;
    $bp->media->table_media_data = $wpdb->base_prefix . 'bp_media_data';
    $p = $wpdb->query("UPDATE {$bp->media->table_media_data} SET views = views + 1  WHERE ID = {$image_id} ");
    die();
}
add_action('wp_ajax_media_view_update', 'media_view_update_callback');
add_action('wp_ajax_nopriv_media_view_update', 'media_view_update_callback');


function media_delete_server_callback() {
    global $bp,$kaltura_validation_data,$wpdb;
    $media_id = $_POST['media_id'];
//    echo $media_id;
    $e_id = $wpdb->get_var("SELECT entry_id from {$bp->media->table_media_data} WHERE ID = {$media_id} ");
    if (isMediaOwner($media_id)) {
        $pic = new BP_Media_Picture($picture_id);
        if ( !$pic->delete() ) {
            echo ('Error / ');
        }
        else {
            $kaltura_validation_data['client']->media->delete($e_id);
            echo "Successfully deleted from server";
            //redireect code
        }
    }
    else {
        echo "Error Deleting from server";
    }
    die();
}
add_action('wp_ajax_media_delete_server', 'media_delete_server_callback');
add_action('wp_ajax_nopriv_media_delete_server', 'media_delete_server_callback');


function media_delete_local_callback( ) {
    global $bp;
    // what u have deleted? audio / video / photo

    $media_id = $_POST['media_id'];
    if (isMediaOwner($media_id)) {
        $pic = new BP_Media_Picture($media_id);

        if ( !$pic->delete() ) {
            echo "Error !!!";
        }
        else {
            echo "Successfully deleted !!!@#$@#audio OR video OR photo";
        }
    }
}
add_action('wp_ajax_media_delete_local', 'media_delete_local_callback');
add_action('wp_ajax_nopriv_media_delete_local', 'media_delete_local_callback');



?>
